"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.humanNumber = void 0;
const as_decimal_1 = require("./as-decimal");
const format_number_1 = require("./format-number");
const ONE_TRILLION = (0, as_decimal_1.asDecimal)(1e12);
const ONE_BILLION = (0, as_decimal_1.asDecimal)(1e9);
const ONE_MILLION = (0, as_decimal_1.asDecimal)(1e6);
/**
 * Convert a Decimal-Like param (string, number, Decimal) to a human-readable number in a string.
 *
 * @param value The DecimalLike number to convert to a human-readable number.
 * @param opts The options to use when converting the number to a human-readable number.
 * @param opts.useWords If true, use full words, instead of abbreviations (e.g. 'billion' instead of 'B')
 * @returns
 */
const humanNumber = (value, { useWords } = {}) => {
    const number = (0, as_decimal_1.asDecimal)(value);
    if (number.abs().gte(ONE_TRILLION)) {
        return (number
            .div(ONE_TRILLION)
            .toFixed(3)
            .replace(/\.?0+$/, "") + (useWords ? " trillion" : "T"));
    }
    else if (number.abs().gte(ONE_BILLION)) {
        return (number
            .div(ONE_BILLION)
            .toFixed(2)
            .replace(/\.?0+$/, "") + (useWords ? " billion" : "B"));
    }
    else if (number.abs().gte(ONE_MILLION)) {
        return (number
            .div(ONE_MILLION)
            .toFixed(1)
            .replace(/\.?0+$/, "") + (useWords ? " million" : "M"));
    }
    else if (number.abs().gte(1000)) {
        return (number
            .div(1000)
            .toFixed(2)
            .replace(/\.?0+$/, "") + (useWords ? " thousand" : "K"));
    }
    else {
        return (0, format_number_1.formatNumber)(number, { numDecimals: 2 });
    }
};
exports.humanNumber = humanNumber;
